%define	version	2.0
%define release 12mdk

Summary:	A set of GNU utilities commonly used in shell scripts
Name:		sh-utils
Version:	%{version}
Release:	%{release}
Copyright:	GPL
Group:		System/Base
Source:		ftp://ftp.gnu.org/pub/gnu/sh-utils-%{version}.tar.bz2
Source1:	su.pamd
Source2:	sh-utils-2.0e-pofiles.tar.bz2
Patch1:		sh-utils-2.0-hostname.patch.bz2
Patch2:		sh-utils-2.0-utmp.patch.bz2
Patch3:		sh-utils-1.16-mktime.patch.bz2
Patch4:		sh-utils-1.16-paths.patch.bz2
Patch5:		sh-utils-2.0-aclocal.patch.bz2
Patch6:		sh-utils-2.0-pam.patch.bz2
Patch7:		sh-utils-2.0-cest.patch.bz2
Patch8:		sh-utils-2.0-utf8.patch.bz2
Buildroot:	%{_tmppath}/sh-utils
Requires:	pam >= 0.66-12
Prereq:		/sbin/install-info
Prefix: %{_prefix}

%description
The GNU shell utilities are a set of useful system utilities which are often
used in shell scripts.

The sh-utils package includes:
  * basename: to remove the path prefix from a specified pathname,
  * chroot: to change the root directory,
  * date: to print/set the system time and date,
  * dirname: to remove the last level or the filename from a given path,
  * echo: to print a line of text,
  * env: to display/modify the environment,
  * expr: to evaluate expressions,
  * factor: to print prime factors,
  * false: to return an unsuccessful exit status,
  * groups: to print the groups a specified user is a member of,
  * id: to print the real/effective uid/gid,
  * logname: to print the current login name,
  * nice: to modify a scheduling priority,
  * nohup: to allow a command to continue running after logging out,
  * pathchk: to check a file name's portability,
  * printenv: to print environment variables,
  * printf: to format and print data,
  * pwd: to print the current directory,
  * seq: to print numeric sequences,
  * sleep: to suspend execution for a specified time,
  * stty: to print/change terminal settings,
  * su: to become another user or the superuser,
  * tee: to send output to multiple files,
  * test: to evaluate an expression,
  * true: to return a successful exit status,
  * tty: to print the terminal name,
  * uname: to print system information,
  * users: to print current users' names,
  * who: to print a list of the users who are currently logged in,
  * whoami: to print the effective user id,
  * yes: to print a string indefinitely.

%prep

%setup -q
%patch1 -p1 -b .chmou
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1 -b .pam
%patch7 -p1
%patch8 -p1
find . -name \*.orig -exec rm -fv {} \;

# XXX docs should say /var/run/[uw]tmp not /etc/[uw]tmp
perl -pi -e 's,/etc/utmp,/var/run/utmp,g' doc/sh-utils.texi man/logname.1 man/users.1 man/who.1
perl -pi -e 's,/etc/wtmp,/var/run/wtmp,g' doc/sh-utils.texi man/logname.1 man/users.1 man/who.1
rm -f doc/sh-utils.info

%build
%configure --disable-largefile --enable-pam
make all info LIBS="-lpam -lpam_misc"

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/{bin,etc/pam.d,%{_sbindir}}

%makeinstall

mkdir -p $RPM_BUILD_ROOT/bin
for i in basename date echo false nice pwd sleep stty true uname ; do
    mv $RPM_BUILD_ROOT%{_bindir}/$i $RPM_BUILD_ROOT/bin/$i
done

install -s src/su $RPM_BUILD_ROOT/bin
# XXX this really should be a %attr ...
chmod 4755 $RPM_BUILD_ROOT/bin/su

mv -f $RPM_BUILD_ROOT%{_bindir}/chroot $RPM_BUILD_ROOT%{_sbindir}/

rm -f $RPM_BUILD_ROOT%{_bindir}/[
ln -sf test $RPM_BUILD_ROOT%{_bindir}/[

mkdir -p $RPM_BUILD_ROOT/etc/pam.d
install -m644 ${RPM_SOURCE_DIR}/su.pamd $RPM_BUILD_ROOT/etc/pam.d/su

# it is in fact zh_TW.Big5; correcting it...
[ ! -r po/zh_TW.Big5.po -a -r po/zh.po ] && (
	mv po/zh.po po/zh_TW.Big5.po 
	cd $RPM_BUILD_ROOT%{_datadir}/locale/
	mv zh zh_TW.Big5
)

# install languages by hand
for i in $RPM_SOURCE_DIR/%{name}-*pofiles.tar.bz2 ; do
        tar Ixkvf $i || :
done
for i in po/*.po ; do
  mkdir -p $RPM_BUILD_ROOT%{_datadir}/locale/`basename $i .po`/LC_MESSAGES
  msgfmt -v -o $RPM_BUILD_ROOT%{_datadir}/locale/`basename $i .po`/LC_MESSAGES/%{name}.mo $i
done


pushd $RPM_BUILD_ROOT && {
for i in hostname uptime ; do
    rm -f .%{_bindir}/$i .%{_mandir}/man1/${i}.1
done
} && popd

%find_lang %{name}

%clean
rm -rf $RPM_BUILD_ROOT

%post
%_install_info %{name}.info

%preun
%_remove_install_info %{name}.info

%files -f %{name}.lang
%defattr(-,root,root)
%doc NEWS README
%config /etc/pam.d/su
%attr(4755,root,root) /bin/su
/bin/basename
/bin/date
/bin/echo
/bin/false
/bin/nice
/bin/pwd
/bin/sleep
/bin/stty
/bin/true
/bin/uname
%{_sbindir}/chroot
%{_bindir}/*
%{_mandir}/man1/*
%{_infodir}/sh-utils.info*

%changelog
* Sun Sep 24 2000 Chmouel Boudjnah <chmouel@mandrakesoft.com> 2.0-12mdk
- Updated pamd configuration.

* Fri Jul 28 2000 Chmouel Boudjnah <chmouel@mandrakesoft.com> 2.0-11mdk
- Remove duplicate uptime (thanks stefan).

* Fri Jul 21 2000 Chmouel Boudjnah <chmouel@mandrakesoft.com> 2.0-10mdk
- Correct macros and filelist.
- Remove hostname manpages since we use the one from net-tools.

* Wed Jul 19 2000 Chmouel Boudjnah <chmouel@mandrakesoft.com> 2.0-9mdk
- Correct build with latest pam.
- Macros.
- BM.

* Mon Jul 03 2000 David BAUDENS <baudens@mandrakesoft.com> 2.0-8mdk
- Fix SRPM installation
- Human readable description

* Mon Jul 03 2000 Pablo Saratxaga <pablo@mandrakesoft.com> 2.0-7mdk
- add utf8 patch to stty from mckinstry@computer.org
- added Irish language catalog

* Fri Mar 31 2000 Chmouel Boudjnah <chmouel@mandrakesoft.com> 2.0-6mdk
- Spec-helper cleanup.
- Adjust groups.
- Use find_lang macros for locales.
- Merge with rh patchs.

* Fri Jan 21 2000 Pablo Saratxaga <pablo@mandrakesoft.com>
- added Catalan and Galician language catalogs
- included catalog languages into the rpm

* Tue Jan 11 2000 Pixel <pixel@linux-mandrake.com>
- fix build as non-root

* Tue Oct 26 1999 Chmouel Boudjnah <chmouel@mandrakesoft.com>
- Merge with redhat changes.

* Mon Aug 16 1999 Bernhard Rosenkraenzer <bero@linux-mandrake.com>
- 2.0

* Sun Aug  8 1999 Bernhard Rosenkraenzer <bero@linux-mandrake.com>
- 1.16m
- clean up .spec file; merge the two PAM patches to one
- remove some obsolete patches

* Fri Jul 16 1999 Chmouel Boudjnah <chmouel@mandrakesoft.com>
- Move %{_bindir}/tty to /bin/ and make a link for backward compatibility.

* Mon Jul 12 1999 Chmouel Boudjnah <chmouel@mandrakesoft.com>

- Build release (25mdk).

* Sat Jul 10 1999 Pablo Saratxaga <srtxg@chanae.alphanet.ch>
- added my patch that makes it for "who" not to do dns calls for 
  "machine names" which are in fact modem speed connections; as used
  by mgetty (ex: obituary ttyS2    Jul 10 18:14 (31200/ARQ) )
- included locale files (why it is that so many packages don't include
  them ? )

* Mon May 10 1999 Pixel <pixel_@geocities.com>
- hacked out restriction on su (stdin isatty now not checked)

* Tue Apr 13 1999 Chmouel Boudjnah <chmouel@mandrakesoft.com>
- Add RedHat6.0 patches.

* Sat Apr 10 1999 Bernhard Rosenkraenzer <bero@linux-mandrake.com>
- Mandrake adaptions
- bzip2 man/info pages
- add de locale
- fix handling of RPM_OPT_FLAGS

* Fri Dec 18 1998 Cristian Gafton <gafton@redhat.com>
- build against glibc 2.1

* Mon Jun  8 1998 Michal Jaegermann <michal@harddata.com>
- fixed reversed test for when to allocate in who.c and an incorrect
  use of xrealloc.

* Thu Apr 30 1998 Donnie Barnes <djb@redhat.com>
- moved %{_bindir}/nice to /bin/nice

* Fri Apr 24 1998 Prospector System <bugs@redhat.com>
- translations modified for de, fr, tr

* Sat Apr 11 1998 Cristian Gafton <gafton@redhat.com>
- manhattan rebuild

* Wed Oct 22 1997 Michael K. Johnson <johnsonm@redhat.com>
- added minor patch for glibc 2.1

* Wed Oct 21 1997 Cristian Gafton <gafton@redhat.com>
- fixed the URLs in spec file
- cleaned up the spec file

* Thu Oct 02 1997 Michael K. Johnson <johnsonm@redhat.com>
- BuildRoot
- New pam standard.

* Sun Sep 14 1997 Erik Troan <ewt@redhat.com>
- uses install-info

* Mon Jun 02 1997 Erik Troan <ewt@redhat.com>
- built against glibc

* Fri Apr 18 1997 Michael K. Johnson <johnsonm@redhat.com>
- Fixed the sense of the user and root default paths.

* Mon Apr 14 1997 Erik Troan <ewt@redhat.com>
- Fixed getutent patch to define UTMP_READ_INCR
- Modified su.c to define default paths w/o regard to other header files or
  -D style definitions

* Wed Apr 02 1997 Erik Troan <ewt@redhat.com>
- Updated getutent patch for 1.16
- Added mktime patch for 64bit time_t

* Tue Mar 25 1997 Michael K. Johnson <johnsonm@redhat.com>
- DEFPATH handling moved from ...path.patch to _PATH_DEFPATH*

* Mon Mar 03 1997 Michael K. Johnson <johnsonm@redhat.com>
- Moved from pam.conf to pam.d
